from setuptools import setup

setup(name='akramcul',
      version='0.0',
      description='Just for fun, doesn\'t contains any useful function',
      packages=['akramcul'],
      author_email='akramMohamed123@gamil.com',
      zip_safe=False)
